@@ -106,15 +106,20 @@ mod tests {
                 println!("[Record Message] Timestamp: {} Latitude: {} Longitude: {} Altitude: {}", timestamp, latitude, longitude, altitude);
             }
             else {
-                println!("Invalid location data");
+                println!("[Record Message] Invalid location data");
             }
         }
+        else if global_message_num == crate::fit_file::GLOBAL_MSG_NUM_LENGTH {
+            // Increment the number of records processed.
+            let data: &mut Context = unsafe { &mut *(context as *mut Context) };
+            data.num_length_msgs_processed = data.num_length_msgs_processed + 1;
+        }
         else {
             let global_message_names = crate::fit_file::init_global_msg_name_map();
             let mut field_num = 1;
 
             match global_message_names.get(&global_message_num) {
-                Some(name) => print!("[{} Message Local Message Type {}] Timestamp {}, Values: ", name, local_msg_type, timestamp),
+                Some(name) => print!("[{} Message] Timestamp {}, Values: ", name, timestamp),
                 None => print!("[Global Message Num {} Local Message Type {}] Timestamp {}, Values: ", global_message_num, local_msg_type, timestamp)
             }
 
@@ -123,15 +128,15 @@ mod tests {
 
                 match field.field_type {
                     crate::fit_file::FieldType::FieldTypeNotSet => { print!("[not set] "); },
-                    crate::fit_file::FieldType::FieldTypeUInt => { print!("{} ", field.num_uint); },
-                    crate::fit_file::FieldType::FieldTypeSInt => { print!("{} ", field.num_sint); },
-                    crate::fit_file::FieldType::FieldTypeFloat => { print!("{} ", field.num_float); },
+                    crate::fit_file::FieldType::FieldTypeUInt => { print!("{} ", field.value_uint); },
+                    crate::fit_file::FieldType::FieldTypeSInt => { print!("{} ", field.value_sint); },
+                    crate::fit_file::FieldType::FieldTypeFloat => { print!("{} ", field.value_float); },
                     crate::fit_file::FieldType::FieldTypeByteArray => {
-                        for byte in field.byte_array.iter() {
+                        for byte in field.value_byte_array.iter() {
                             print!("{:#04x} ", byte);
                         }
                     },
-                    crate::fit_file::FieldType::FieldTypeStr => { print!("\"{}\" ", field.string); },
+                    crate::fit_file::FieldType::FieldTypeStr => { print!("\"{}\" ", field.value_string); },
                 }
 
                 field_num = field_num + 1;
@@ -143,12 +148,13 @@ mod tests {
     /// Context structure. An instance of this will be passed to the parser and ultimately to the callback function so we can use it for whatever.
     struct Context {
         num_records_processed: u16,
+        num_length_msgs_processed: u16,
         accumulated_power: u64
     }
 
     impl Context {
         pub fn new() -> Self {
-            let context = Context{ num_records_processed: 0, accumulated_power: 0 };
+            let context = Context{ num_records_processed: 0, num_length_msgs_processed: 0, accumulated_power: 0 };
             context
         }
     }
@@ -255,6 +261,26 @@ mod tests {
         }
     }
 
+    #[test]
+    fn file5_pool_swim() {
+        let file = std::fs::File::open("tests/20210709_pool_swim.fit").unwrap();
+        let mut reader = std::io::BufReader::new(file);
+        let mut context = Context::new();
+        let context_ptr: *mut c_void = &mut context as *mut _ as *mut c_void;
+        let fit = crate::fit_file::read(&mut reader, callback, context_ptr);
+
+        match fit {
+            Ok(fit) => {
+                print!("FIT File Header: ");
+                fit.header.print();
+                println!("");
+                println!("Num records processed: {}", context.num_length_msgs_processed);
+                assert!(context.num_length_msgs_processed == 55);
+            }
+            _ => (),
+        }
+    }
+
     fn convert_to_camel_case(name: &String) -> String {
         let mut new_name = String::new();
         let mut need_upper_case = true;
@@ -303,11 +329,13 @@ mod tests {
         println!("        }};");
         println!("");
         println!("        for field in fields {{");
-        println!("            match field.field_def {{");
+        println!("            if !field.is_dev_field {{");
+        println!("                match field.field_def {{");
         for (field_name, (field_id, field_type)) in field_map.iter() {
-            println!("                {} => {{ msg.{} = Some(field.get_{}()); }},", field_id, field_name, *field_type);
+            println!("                    {} => {{ msg.{} = Some(field.get_{}()); }},", field_id, field_name, *field_type);
         }
         println!("");
+        println!("                }}");
         println!("            }}");
         println!("        }}");
         println!("        msg");
